@@ -2,8 +2,9 @@ import json
 import os
 import sys
 from .protocols import HFE, HTTPDATA, HTTPOutgoing
-import importlib
+import imp
 import gzip, shutil
+import traceback
 
 
 class Extension:
@@ -22,30 +23,23 @@ uponAddToServer MUST return the name of the extension, for later use obviously.'
 
 
 class PyHP(Extension):
-    def uponAddToServer(self,index="index.py"):
-        print("Added to server")
-        self.index=index
-        self.server.getHook("http_handle").addFunction(self.handle)
+    def inittasks(self,config={}):
+        self.config={"index":"index.pyhp"}
+        self.config.update(config)
+    def uponAddToServer(self):
+        self.server.getHook("httprecv").addFunction(self.handle)
         return "pyhp" ## Extensions should always return a name
-    def handle(self,incoming,outgoing):
+    def handle(self,incoming):
         try:
-            locale=None
-            if incoming.location[-3:]==".py":
-                locale=incoming.location[:-3]
-            if os.path.exists(incoming.location+".py"):
-                locale=incoming.location
-            print(incoming.location)
-            if incoming.location[-1]=="/" and os.path.exists(incoming.location+self.index):
-                locale=incoming.location+self.index
-            if locale:
-                i=importlib.import_module(os.path.relpath(locale).replace("/","."))
-                for x in HTTPDATA.methods:
-                    if hasattr(i,"handle_"+x.lower()):
-                        data,status=i.__getattribute__("handle_"+x.lower())(incoming)
-                        outgoing.setStatus(status)
-                        outgoing.setContent(data)
+            locale=incoming.rqstdt["uri"]
+            if locale.endswith(".pyhp"):
+                i=imp.load_source("Imported",locale)
+                if hasattr(i,"handle"+incoming.rqstdt["httpmethod"].lower()):
+                    data=i.__getattribute__("handle"+incoming.rqstdt["httpmethod"].lower())(incoming,self.server) ## Should return a tuple with the first element being the event status code, and the second element being the content
+                    incoming.rspnsdt["resultcode"]=data[0]
+                    incoming.rspnsdt["content"]=data[1]
         except Exception as e:
-            print(e)
+            traceback.print_exc()
 
 
 class SimpleGzipper(Extension):
@@ -58,23 +52,19 @@ files. Stores the gzipped files in a cache.'''
         if not os.path.exists(cachelocale+"md5caches"):
             p=open(cachelocale+"md5caches","w+")
             p.close()
-        self.server.getHook("http_handleGET").addFunction(self.handle)
-        print("SimpleGzipper has been added!")
+        self.server.getHook("httprecv").addFunction(self.handle)
         return "SimpleGzipper"
     def isCacheInvalid(self,filename):
-        print("Checking SimpleGzipper cache...")
         data=self.openCache()
         crmtime=os.path.getmtime(filename)
         if (not filename in data) or (crmtime!=data[filename]):
             return True
         return False
     def validateCache(self,filename):
-        print("Validating SimpleGzipper cache...")
         d=self.openCache()
         d[filename]=str(os.path.getmtime(filename))
         self.writeCache(d)
     def writeCache(self,ncache):
-        print("Writing SimpleGzipper cache")
         file=open(self.cachelocale+"md5caches","w")
         data=""
         for x,y in ncache.items():
@@ -82,36 +72,33 @@ files. Stores the gzipped files in a cache.'''
         file.write(data)
         file.close()
     def openCache(self):
-        print("Opening SimpleGzipper cache")
         file=open(self.cachelocale+"md5caches")
         data=file.read()
         file.close()
-        print(data)
         d=data.split("\n")[:-1] ## Use all but the last, unfilled, line.
-        print(d)
         returner={}
         for x in d:
             ps=x.split(" : ")
-            print(ps)
             returner[ps[0]]=float(ps[1])
         return returner
-    def handle(self,incoming,outgoing):
+    def handle(self,incoming):
         ## Only do any of this if outgoing has a file send
-        print("Handling, in SimpleGzipper")
-        if os.path.isfile(incoming.location) and outgoing.filename and "gzip" in incoming.headers["Accept-Encoding"]:
-            print("Made it past the first IfGate in SimpleGzipper/handle")
-            location=incoming.location.replace("/",".")
-            if self.isCacheInvalid(incoming.location):
-                print("SimpleGzipper cache is invalid for "+location)
-                self.validateCache(incoming.location)
-                file=open(incoming.location,"rb")
-                gzipped=gzip.open(self.cachelocale+'"'+location+'.gz"',"wb")
-                shutil.copyfileobj(file,gzipped)
-                file.close()
-                gzipped.close()
-            outgoing.setFile(self.cachelocale+'"'+location+'.gz"')
-            outgoing.addHeader("Content-Encoding","gzip")
-        return True
+        try:
+            if os.path.isfile(incoming.rqstdt["uri"]) and not (incoming.rqstdt["uri"].endswith(".pyhp") and "pyhp" in self.server.extensions) and "Accept-Encoding" in incoming.rqstdt["headers"] and "gzip" in incoming.rqstdt["headers"]["Accept-Encoding"]:
+                location=incoming.rqstdt["uri"].replace("/",".")
+                print("Doing actual handling in gzipper")
+                print("BTW, the current URI is",incoming.rqstdt["uri"])
+                if self.isCacheInvalid(incoming.rqstdt["uri"]):
+                    self.validateCache(incoming.rqstdt["uri"])
+                    file=open(incoming.rqstdt["uri"],"rb")
+                    gzipped=gzip.open(self.cachelocale+'"'+location+'.gz"',"wb")
+                    shutil.copyfileobj(file,gzipped)
+                    file.close()
+                    gzipped.close()
+                incoming.rqstdt["uri"]=self.cachelocale+'"'+location+'.gz"'
+                incoming.rspnsdt["headers"]["Content-Encoding"]="gzip"
+        except:
+            traceback.print_exc()
 
 
 class IncrediblySimpleWebSend(Extension):
@@ -126,37 +113,49 @@ class IncrediblySimpleWebSend(Extension):
         return "IS-Websend"
     def httprecv(self,incoming):
         if incoming.rqstdt["httpmethod"]=="GET":
-            o=HTTPOutgoing(incoming)
-            if os.path.isfile(incoming.rqstdt["uri"]):
-                o.setFile(incoming.rqstdt["uri"])
-            else:
-                if self.config["404"][0]=="inline":
-                    o.setContent(self.config["404"][1])
-                elif self.config["404"][0]=="file":
-                    o.setFile(self.config["404"][1])
-            o.send()
+            print("Will send")
+            try:
+                o=HTTPOutgoing(incoming)
+                if os.path.isfile(incoming.rqstdt["uri"]):
+                    o.setFile(incoming.rqstdt["uri"])
+                else:
+                    if self.config["404"][0]=="inline":
+                        o.setContent(self.config["404"][1])
+                    elif self.config["404"][0]=="file":
+                        o.setFile(self.config["404"][1])
+                    o.status=404 ## Not a file.
+                o.send()
+            except:
+                traceback.print_exc()
+            print("Sent!")
 
 
 class URISterilizer(Extension):
     def inittasks(self,config={}):
-        self.config={"relativepaths":True,"noparentdir":True,"primeforwebsend":True,"useindexindirectory":True,"completehtmlfileextension":True}
+        self.config={"relativepaths":True,"noparentdir":True,"primeforwebsend":True,"useindexindirectory":True,"completehtmlfileextension":True,"primeforpyhp":True}
         self.config.update(config)
     def uponAddToServer(self):
         self.server.getHook("httprecv").addFunction(self.httprecv)
         return "URISterilizer"
     def httprecv(self,incoming):
         uri=incoming.rqstdt["uri"]
-        print(uri)
         if self.config["relativepaths"]==True and uri[0]=="/": uri=uri[1:]
         if self.config["noparentdir"]==True and "../" in uri: uri.replace("../","")
         if self.config["primeforwebsend"]==True: ## Designed for compatibility with the WebSend family of HTTP server senders
-            print(self.server.extensions)
             if "IS-Websend" in self.server.extensions: ## Incredibly Simple WebSend
                 websconfig=self.server.extensions["IS-Websend"].config
                 uri=websconfig["sitedir"]+("/" if not websconfig["sitedir"][-1]=="/" else "")+uri
-                print(uri+("/" if uri[-1]!="/" else "")+websconfig["index"])
                 if self.config["useindexindirectory"]==True and os.path.isfile(uri+("/" if not uri[-1]=="/" else "")+websconfig["index"]):
                     uri+=("/" if not uri[-1]=="/" else "")+websconfig["index"]
                 if self.config["completehtmlfileextension"]==True and os.path.isfile(uri+".html"):
                     uri+=".html"
+        try:
+            if "pyhp" in self.server.extensions and self.config["primeforpyhp"]==True: ## PyHp
+                pyhpconfig=self.server.extensions["pyhp"].config
+                if os.path.exists(uri+".pyhp"):
+                    uri+=".pyhp"
+                if uri[-1]=="/" and os.path.exists(uri+pyhpconfig["index"]):
+                    uri+=pyhpconfig["index"]
+        except:
+            traceback.print_exc()
         incoming.rqstdt["uri"]=uri
